@@ -11,13 +11,31 @@ testthat::test_that("Check locales are equal to ms_locales", {
     # standard voices not neural
     index = sapply(tab, function(x) {
       if (!"Voice name" %in% colnames(x)) {
-        return(FALSE)
+        return(NA_character_)
       }
       x = x[, "Voice name", drop = TRUE]
-      !any(grepl("Neural", x))
+      ifelse(any(grepl("Neural", x)), "neural", "regular")
     })
-    index = which(index)
-    tab = tab[[index]]
+    keep = which(index %in% "regular")
+    if (length(keep) == 0) {
+      keep = which(index %in% "neural")
+    }
+    index = keep
+    tab = tab[index]
+    tab = lapply(tab, function(x) {
+      colnames(x) = sub("(BCP-47)", "", colnames(x), fixed = TRUE)
+      cn = colnames(x)
+      if (!all(c("Locale", "Language") %in% cn)) {
+        return(NULL)
+      }
+      x[, c("Locale", "Language")]
+    })
+    tab = do.call(rbind, tab)
+    colnames(tab) = sub("(BCP-47)", "", colnames(tab), fixed = TRUE)
+    colnames(tab) = trimws(colnames(tab))
+
+    Encoding(tab$Locale) = "UTF-8"
+    Encoding(tab$Language) = "UTF-8"
 
     sub_tab = tab[, c("Locale", "Language")]
     sub_tab$Locale = gsub("[*]", "",     sub_tab$Locale)
@@ -31,7 +49,8 @@ testthat::test_that("Check locales are equal to ms_locales", {
     df = mscstts::ms_locale_df()
     sub_tab$language = sub("Ã¥", "å", sub_tab$language)
 
-    testthat::expect_equal(sort(unique(sub_tab$language)),
-                           sort(unique(df$language)))
+    tab_lang = sort(unique(sub_tab$language))
+    df_lang = sort(unique(df$language))
+    testthat::expect_equal(tab_lang, df_lang)
   }
 })
